@@ -257,12 +257,11 @@ static bfd *lineno_cache_rel_bfd;
 
 #define OPTION_TARGET 200
 #define OPTION_DEMANGLER (OPTION_TARGET + 1)
-#define OPTION_STYLE (OPTION_DEMANGLER + 1)
 
 static struct option long_options[] =
 {
   {"debug-syms", no_argument, &print_debug_syms, 1},
-  {"demangle", no_argument, &do_demangle, 1},
+  {"demangle", optional_argument, 0, 'C'},
   {"demangler", required_argument, NULL, OPTION_DEMANGLER},
   {"dynamic", no_argument, &dynamic, 1},
   {"extern-only", no_argument, &external_only, 1},
@@ -281,7 +280,6 @@ static struct option long_options[] =
   {"size-sort", no_argument, &sort_by_size, 1},
   {"stats", no_argument, &show_stats, 1},
   {"target", required_argument, 0, OPTION_TARGET},
-  {"style", required_argument, NULL, OPTION_STYLE},
   {"defined-only", no_argument, &defined_only, 1},
   {"undefined-only", no_argument, &undefined_only, 1},
   {"version", no_argument, &show_version, 1},
@@ -295,21 +293,41 @@ usage (stream, status)
      FILE *stream;
      int status;
 {
-  fprintf (stream, _("\
-Usage: %s [-aABCDglnopPrsuvV] [-t radix] [--radix=radix] [--target=bfdname]\n\
-       [--debug-syms] [--extern-only] [--print-armap] [--print-file-name]\n\
-       [--numeric-sort] [--no-sort] [--reverse-sort] [--size-sort]\n\
-       [--undefined-only] [--portability] [-f {bsd,sysv,posix}]\n\
-       [--format={bsd,sysv,posix}] [--demangle] [--no-demangle]\n\
-       [--demangler=dso:function]\n"), program_name);
-  fprintf (stream, _("\
-       [--style=%s]\n\
-       [--dynamic] [--defined-only] [--line-numbers]\n\
-       [--version] [--help]\n\
-       [file...]\n"), get_demangler_list ());
+  fprintf (stream, _("Usage: %s [OPTION]... [FILE]...\n"), program_name);
+  fprintf (stream, _("List symbols from FILEs (a.out by default).\n"));
+  fprintf (stream, _("\n\
+  -a, --debug-syms       Display debugger-only symbols\n\
+  -A, --print-file-name  Print name of the input file before every symbol\n\
+  -B                     Same as --format=bsd\n\
+  -C, --demangle[=%s]\n\
+                         Decode low-level symbol names into user-level names\n\
+      --no-demangle      Do not demangle low-level symbol names\n\
+      --demangler=<dso:function>\n\
+			 Set dso and demangler function\n\
+  -D, --dynamic          Display dynamic symbols instead of normal symbols\n\
+      --defined-only     Display only defined symbols\n\
+  -e                     (ignored)\n\
+  -f, --format=FORMAT    Use the output format FORMAT.  FORMAT can be `bsd',\n\
+                           `sysv' or `posix'.  The default is `bsd'\n\
+  -g, --extern-only      Display only external symbols\n\
+  -h, --help             Display this information\n\
+  -l, --line-numbers     Use debugging information to find a filename and\n\
+                           line number for each symbol\n\
+  -n, --numeric-sort     Sort symbols numerically by address\n\
+  -o                     Same as -A\n\
+  -p, --no-sort          Do not sort the symbols\n\
+  -P, --portability      Same as --format=posix\n\
+  -r, --reverse-sort     Reverse the sense of the sort\n\
+  -s, --print-armap      Include index for symbols from archive members\n\
+      --size-sort        Sort symbols by size\n\
+  -t, --radix=RADIX      Use RADIX for printing symbol values\n\
+      --target=BFDNAME   Specify the target object format as BFDNAME\n\
+  -u, --undefined-only   Display only undefined symbols\n\
+  -V, --version          Display this program's version number\n\
+\n"), get_demangler_list ());
   list_supported_targets (program_name, stream);
   if (status == 0)
-    fprintf (stream, _("Report bugs to %s\n"), REPORT_BUGS_TO);
+    fprintf (stream, _("Report bugs to %s.\n"), REPORT_BUGS_TO);
   exit (status);
 }
 
@@ -395,7 +413,8 @@ main (argc, argv)
   bfd_init ();
   set_default_bfd_target ();
 
-  while ((c = getopt_long (argc, argv, "aABCDef:glnopPrst:uvV", long_options, (int *) 0)) != EOF)
+  while ((c = getopt_long (argc, argv, "aABCDef:glnopPrst:uvV",
+			   long_options, (int *) 0)) != EOF)
     {
       switch (c)
 	{
@@ -411,6 +430,8 @@ main (argc, argv)
 	  break;
 	case 'C':
 	  do_demangle = 1;
+	  if (optarg != NULL)
+	    style = optarg;
 	  break;
 	case 'D':
 	  dynamic = 1;
@@ -463,10 +484,6 @@ main (argc, argv)
 	  demangler = optarg;
 	  break;
 
-	case OPTION_STYLE:
-	  style = optarg;
-	  break;
-
 	case 0:		/* A long option that just sets a flag.  */
 	  break;
 
