@@ -1,5 +1,6 @@
 /* ECOFF object file format.
-   Copyright (C) 1993, 94, 95, 96, 97, 98, 1999 Free Software Foundation, Inc.
+   Copyright (C) 1993, 94, 95, 96, 97, 98, 99, 2000
+   Free Software Foundation, Inc.
    Contributed by Cygnus Support.
    This file was put together by Ian Lance Taylor <ian@cygnus.com>.
 
@@ -33,6 +34,7 @@
 static int ecoff_sec_sym_ok_for_reloc PARAMS ((asection *));
 static void obj_ecoff_frob_symbol PARAMS ((symbolS *, int *));
 static void ecoff_pop_insert PARAMS ((void));
+static int ecoff_separate_stab_sections PARAMS ((void));
 
 /* These are the pseudo-ops we support in this file.  Only those
    relating to debugging information are supported here.
@@ -289,22 +291,43 @@ ecoff_pop_insert ()
   pop_insert (obj_pseudo_table);
 }
 
+static int
+ecoff_separate_stab_sections ()
+{
+  return 0;
+}
+
 const struct format_ops ecoff_format_ops =
 {
   bfd_target_ecoff_flavour,
-  0,
-  1,
+  0,	/* dfl_leading_underscore */
+
+  /* FIXME: A comment why emit_section_symbols is different here (1) from
+     the single-format definition (0) would be in order.  */
+  1,	/* emit_section_symbols */
+  0,	/* begin */
+  ecoff_new_file,
   obj_ecoff_frob_symbol,
   ecoff_frob_file,
-  0,
-  0, 0,
-  0, 0,
-  0,
+  0,	/* frob_file_after_relocs */
+  0,	/* s_get_size */
+  0,	/* s_set_size */
+  0,	/* s_get_align */
+  0,	/* s_set_align */
+  0,	/* s_get_other */
+  0,	/* s_set_other */
+  0,	/* s_get_desc */
+  0,	/* s_set_desc */
+  0,	/* s_get_type */
+  0,	/* s_set_type */
+  0,	/* copy_symbol_attributes */
   ecoff_generate_asm_lineno,
   ecoff_stab,
+  ecoff_separate_stab_sections,
+  0,	/* init_stab_section */
   ecoff_sec_sym_ok_for_reloc,
   ecoff_pop_insert,
   ecoff_set_ext,
   ecoff_read_begin_hook,
-  ecoff_symbol_new_hook,
+  ecoff_symbol_new_hook
 };
