@@ -1,5 +1,6 @@
 /* tc-a29k.c -- Assemble for the AMD 29000.
-   Copyright (C) 1989, 1990, 1991, 1992, 1993 Free Software Foundation, Inc.
+   Copyright (C) 1989, 90, 91, 92, 93, 94, 95, 1998
+   Free Software Foundation, Inc.
 
    This file is part of GAS, the GNU Assembler.
 
@@ -14,8 +15,9 @@
    GNU General Public License for more details.
 
    You should have received a copy of the GNU General Public License
-   along with GAS; see the file COPYING.  If not, write to
-   the Free Software Foundation, 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.  */
+   along with GAS; see the file COPYING.  If not, write to the Free
+   Software Foundation, 59 Temple Place - Suite 330, Boston, MA
+   02111-1307, USA.  */
 
 /* John Gilmore has reorganized this module somewhat, to make it easier
    to convert it to new machines' assemblers as desired.  There was too
@@ -77,8 +79,6 @@ md_pseudo_table[] =
   {NULL, 0, 0},
 };
 
-int md_short_jump_size = 4;
-int md_long_jump_size = 4;
 #if defined(BFD_HEADERS)
 #ifdef RELSZ
 const int md_reloc_size = RELSZ;	/* Coff headers */
@@ -157,7 +157,7 @@ s_use (ignore)
       return;
     }
 
-  as_bad ("Unknown segment type");
+  as_bad (_("Unknown segment type"));
   demand_empty_rest_of_line ();
 }
 
@@ -327,7 +327,7 @@ md_begin ()
     }
 
   if (lose)
-    as_fatal ("Broken assembler.  No assembly attempted.");
+    as_fatal (_("Broken assembler.  No assembly attempted."));
 
   define_some_regs ();
 }
@@ -372,7 +372,7 @@ parse_operand (s, operandp, opt)
   input_line_pointer = s;
   expression (operandp);
   if (operandp->X_op == O_absent && ! opt)
-    as_bad ("missing operand");
+    as_bad (_("missing operand"));
   new = input_line_pointer;
   input_line_pointer = save;
   return new;
@@ -412,12 +412,12 @@ machine_ip (str)
       break;
 
     default:
-      as_bad ("Unknown opcode: `%s'", str);
+      as_bad (_("Unknown opcode: `%s'"), str);
       return;
     }
   if ((insn = (struct machine_opcode *) hash_find (op_hash, str)) == NULL)
     {
-      as_bad ("Unknown opcode `%s'.", str);
+      as_bad (_("Unknown opcode `%s'."), str);
       return;
     }
   argsStart = s;
@@ -449,7 +449,7 @@ machine_ip (str)
 	      the_insn.opcode = opcode;
 	      return;
 	    }
-	  as_bad ("Too many operands: %s", s);
+	  as_bad (_("Too many operands: %s"), s);
 	  break;
 
 	case ',':		/* Must match a comma */
@@ -471,7 +471,7 @@ machine_ip (str)
 		}
 	      else
 		{
-		  as_bad ("Immediate value of %ld is too large",
+		  as_bad (_("Immediate value of %ld is too large"),
 			  (long) operand->X_add_number);
 		  continue;
 		}
@@ -502,7 +502,7 @@ machine_ip (str)
 		}
 	      else
 		{
-		  as_bad ("Immediate value of %ld is too large",
+		  as_bad (_("Immediate value of %ld is too large"),
 			  (long) operand->X_add_number);
 		  continue;
 		}
@@ -541,7 +541,7 @@ machine_ip (str)
 	      opcode |= reg << 16;
 	      continue;
 	    }
-	  as_fatal ("failed sanity check.");
+	  as_fatal (_("failed sanity check."));
 	  break;
 
 	case 'x':		/* 16 bit constant, zero-extended */
@@ -710,8 +710,8 @@ machine_ip (str)
    but I'm not sure.
 
    Turn a string in input_line_pointer into a floating point constant
-   of type type, and store the appropriate bytes in *litP.  The number
-   of LITTLENUMS emitted is stored in *sizeP .  An error message is
+   of type TYPE, and store the appropriate bytes in *LITP.  The number
+   of LITTLENUMS emitted is stored in *SIZEP.  An error message is
    returned, or NULL on OK.  */
 
 /* Equal to MAX_PRECISION in atof-ieee.c */
@@ -889,7 +889,7 @@ md_apply_fix (fixP, val)
 
     case NO_RELOC:
     default:
-      as_bad ("bad relocation type: 0x%02x", fixP->fx_r_type);
+      as_bad (_("bad relocation type: 0x%02x"), fixP->fx_r_type);
       break;
     }
 }
@@ -913,7 +913,7 @@ tc_coff_fix2rtype (fixP)
     case RELOC_JUMPTARG:
       return (R_IREL);
     default:
-      printf ("need %o3\n", fixP->fx_r_type);
+      printf (_("need %o3\n"), fixP->fx_r_type);
       abort ();
     }				/* switch on type */
 
@@ -922,17 +922,6 @@ tc_coff_fix2rtype (fixP)
 
 #endif /* OBJ_COFF */
 
-/* should never be called for 29k */
-void
-md_create_short_jump (ptr, from_addr, to_addr, frag, to_symbol)
-     char *ptr;
-     addressT from_addr, to_addr;
-     fragS *frag;
-     symbolS *to_symbol;
-{
-  as_fatal ("a29k_create_short_jmp\n");
-}
-
 /* should never be called for 29k */
 void
 md_convert_frag (headers, seg, fragP)
@@ -940,19 +929,7 @@ md_convert_frag (headers, seg, fragP)
      segT seg;
      register fragS *fragP;
 {
-  as_fatal ("a29k_convert_frag\n");
-}
-
-/* should never be called for 29k */
-void
-md_create_long_jump (ptr, from_addr, to_addr, frag, to_symbol)
-     char *ptr;
-     addressT from_addr;
-     addressT to_addr;
-     fragS *frag;
-     symbolS *to_symbol;
-{
-  as_fatal ("a29k_create_long_jump\n");
+  as_fatal (_("a29k_convert_frag\n"));
 }
 
 /* should never be called for a29k */
@@ -961,7 +938,7 @@ md_estimate_size_before_relax (fragP, segtype)
      register fragS *fragP;
      segT segtype;
 {
-  as_fatal ("a29k_estimate_size_before_relax\n");
+  as_fatal (_("a29k_estimate_size_before_relax\n"));
   return 0;
 }
 
@@ -1112,7 +1089,7 @@ a29k_unrecognized_line (c)
 
   if (dollar_label_defined (lab))
     {
-      as_bad ("label \"$%d\" redefined", lab);
+      as_bad (_("label \"$%d\" redefined"), lab);
       return 0;
     }
 
@@ -1185,7 +1162,7 @@ md_operand (expressionP)
       (void) expression (expressionP);
       if (expressionP->X_op != O_constant
 	  || expressionP->X_add_number > 255)
-	as_bad ("Invalid expression after %%%%\n");
+	as_bad (_("Invalid expression after %%%%\n"));
       expressionP->X_op = O_register;
     }
   else if (input_line_pointer[0] == '&')
@@ -1196,7 +1173,7 @@ md_operand (expressionP)
       input_line_pointer++;	/* Skip & */
       (void) expression (expressionP);
       if (expressionP->X_op != O_register)
-	as_bad ("Invalid register in & expression");
+	as_bad (_("Invalid register in & expression"));
       else
 	expressionP->X_op = O_constant;
     }
