@@ -18,10 +18,7 @@
    the Free Software Foundation, 59 Temple Place - Suite 330,
    Boston, MA 02111-1307, USA.  */
 
-/*
-   Written By Steve Chamberlain
-   sac@cygnus.com
- */
+/* Written By Steve Chamberlain <sac@cygnus.com>  */
 
 #include <stdio.h>
 #include "as.h"
@@ -65,8 +62,7 @@ little (ignore)
    has to support.  The fields are:
    pseudo-op name without dot
    function to call to execute this pseudo-op
-   Integer arg to pass to the function
- */
+   Integer arg to pass to the function.  */
 
 const pseudo_typeS md_pseudo_table[] =
 {
@@ -102,7 +98,7 @@ static int valid_arch;
 
 const char EXP_CHARS[] = "eE";
 
-/* Chars that mean this number is a floating point constant */
+/* Chars that mean this number is a floating point constant.  */
 /* As in 0f12.456 */
 /* or    0d1.2345e12 */
 const char FLT_CHARS[] = "rRsSfFdDxXpP";
@@ -113,7 +109,7 @@ const char FLT_CHARS[] = "rRsSfFdDxXpP";
 #define ENCODE_RELAX(what,length) (((what) << 4) + (length))
 #define GET_WHAT(x) ((x>>4))
 
-/* These are the three types of relaxable instrction */
+/* These are the three types of relaxable instrction.  */
 #define COND_JUMP 1
 #define COND_JUMP_DELAY 2
 #define UNCOND_JUMP  3
@@ -199,10 +195,8 @@ const relax_typeS md_relax_table[C (END, 0)] = {
 
 static struct hash_control *opcode_hash_control;	/* Opcode mnemonics */
 
-/*
-   This function is called once, at assembler startup time.  This should
-   set up all the tables, etc that the MD part of the assembler needs
- */
+/* This function is called once, at assembler startup time.  This should
+   set up all the tables, etc that the MD part of the assembler needs.  */
 
 void
 md_begin ()
@@ -224,7 +218,7 @@ md_begin ()
 
   opcode_hash_control = hash_new ();
 
-  /* Insert unique names into hash table */
+  /* Insert unique names into hash table.  */
   for (opcode = sh_table; opcode->name; opcode++)
     {
       if (strcmp (prev_name, opcode->name))
@@ -237,7 +231,7 @@ md_begin ()
       else
 	{
 	  /* Make all the opcodes with the same name point to the same
-	     string */
+	     string.  */
 	  opcode->name = prev_name;
 	}
     }
@@ -259,7 +253,8 @@ sh_operand_info;
 
 #define IDENT_CHAR(c) (isalnum (c) || (c) == '_')
 
-/* try and parse a reg name, returns number of chars consumed */
+/* Try to parse a reg name.  Return the number of chars consumed.  */
+
 static int
 parse_reg (src, mode, reg)
      char *src;
@@ -607,7 +602,8 @@ parse_reg (src, mode, reg)
   return 0;
 }
 
-static symbolS *dot()
+static symbolS *
+dot ()
 {
   const char *fake;
 
@@ -618,12 +614,9 @@ static symbolS *dot()
 		      now_seg,
 		      (valueT) frag_now_fix (),
 		      frag_now);
-
 }
 
-
-static
-char *
+static char *
 parse_exp (s, op)
      char *s;
      sh_operand_info *op;
@@ -641,7 +634,6 @@ parse_exp (s, op)
   return new;
 }
 
-
 /* The many forms of operand:
 
    Rn                   Register direct
@@ -659,11 +651,9 @@ parse_exp (s, op)
    disp:12
    #imm8
    pr, gbr, vbr, macl, mach
-
  */
 
-static
-char *
+static char *
 parse_at (src, op)
      char *src;
      sh_operand_info *op;
@@ -673,7 +663,7 @@ parse_at (src, op)
   src++;
   if (src[0] == '-')
     {
-      /* Must be predecrement */
+      /* Must be predecrement.  */
       src++;
 
       len = parse_reg (src, &mode, &(op->reg));
@@ -733,11 +723,12 @@ parse_at (src, op)
 		}
 	      else if (mode == A_PC)
 		{
-		  /* Turn a plain @(4,pc) into @(.+4,pc) */
-		  if (op->immediate.X_op == O_constant) { 
-		    op->immediate.X_add_symbol = dot();
-		    op->immediate.X_op = O_symbol;
-		  }
+		  /* Turn a plain @(4,pc) into @(.+4,pc).  */
+		  if (op->immediate.X_op == O_constant)
+		    {
+		      op->immediate.X_add_symbol = dot();
+		      op->immediate.X_op = O_symbol;
+		    }
 		  op->type = A_DISP_PC;
 		}
 	      else
@@ -820,15 +811,14 @@ get_operand (ptr, op)
     }
   else
     {
-      /* Not a reg, the only thing left is a displacement */
+      /* Not a reg, the only thing left is a displacement.  */
       *ptr = parse_exp (src, op);
       op->type = A_DISP_PC;
       return;
     }
 }
 
-static
-char *
+static char *
 get_operands (info, args, operand)
      sh_opcode_info *info;
      char *args;
@@ -887,11 +877,9 @@ get_operands (info, args, operand)
 
 /* Passed a pointer to a list of opcodes which use different
    addressing modes, return the opcode which matches the opcodes
-   provided
- */
+   provided.  */
 
-static
-sh_opcode_info *
+static sh_opcode_info *
 get_specific (opcode, operands)
      sh_opcode_info *opcode;
      sh_operand_info *operands;
@@ -899,24 +887,26 @@ get_specific (opcode, operands)
   sh_opcode_info *this_try = opcode;
   char *name = opcode->name;
   int n = 0;
+
   while (opcode->name)
     {
       this_try = opcode++;
       if (this_try->name != name)
 	{
 	  /* We've looked so far down the table that we've run out of
-	     opcodes with the same name */
+	     opcodes with the same name.  */
 	  return 0;
 	}
-      /* look at both operands needed by the opcodes and provided by
+
+      /* Look at both operands needed by the opcodes and provided by
          the user - since an arg test will often fail on the same arg
          again and again, we'll try and test the last failing arg the
-         first on each opcode try */
-
+         first on each opcode try.  */
       for (n = 0; this_try->arg[n]; n++)
 	{
 	  sh_operand_info *user = operands + n;
 	  sh_arg_type arg = this_try->arg[n];
+
 	  switch (arg)
 	    {
 	    case A_IMM:
@@ -984,7 +974,7 @@ get_specific (opcode, operands)
 		goto fail;
 	      break;
 
-            case A_REG_B:
+	    case A_REG_B:
 	      if (user->type != arg)
 		goto fail;
 	      reg_b = user->reg;
@@ -1155,7 +1145,7 @@ get_specific (opcode, operands)
 		goto fail;
 	      reg_m = 4;
 	      break;
-	
+
 	    default:
 	      printf (_("unhandled %d\n"), arg);
 	      goto fail;
@@ -1165,7 +1155,8 @@ get_specific (opcode, operands)
 	goto fail;
       valid_arch &= this_try->arch;
       return this_try;
-    fail:;
+    fail:
+      ;
     }
 
   return 0;
@@ -1186,7 +1177,6 @@ check (operand, low, high)
   return operand->X_add_number;
 }
 
-
 static void
 insert (where, how, pcrel, op)
      char *where;
@@ -1236,7 +1226,8 @@ build_relax (opcode, op)
 
 }
 
-/* insert ldrs & ldre with fancy relocations that relaxation can recognize.  */
+/* Insert ldrs & ldre with fancy relocations that relaxation can recognize.  */
+
 static char *
 insert_loop_bounds (output, operand)
      char *output;
@@ -1265,7 +1256,7 @@ insert_loop_bounds (output, operand)
 	 Hence a 9 digit number should be enough to count all REPEATs.  */
       name = alloca (11);
       sprintf (name, "_R%x", count++ & 0x3fffffff);
-      end_sym =  symbol_new (name, undefined_section, 0, &zero_address_frag);
+      end_sym = symbol_new (name, undefined_section, 0, &zero_address_frag);
       /* Make this a local symbol.  */
 #ifdef OBJ_COFF
       SF_SET_LOCAL (end_sym);
@@ -1285,7 +1276,8 @@ insert_loop_bounds (output, operand)
   return frag_more (2);
 }
 
-/* Now we know what sort of opcodes it is, lets build the bytes.  */
+/* Now we know what sort of opcodes it is, let's build the bytes.  */
+
 static void
 build_Mytes (opcode, operand)
      sh_opcode_info *opcode;
@@ -1326,7 +1318,7 @@ build_Mytes (opcode, operand)
 	    case REG_NM:
 	      nbuf[index] = reg_n | (reg_m >> 2);
 	      break;
-            case REG_B:
+	    case REG_B:
 	      nbuf[index] = reg_b | 0x08;
 	      break;
 	    case IMM0_4BY4:
@@ -1381,14 +1373,16 @@ build_Mytes (opcode, operand)
 	    }
 	}
     }
-  if (! target_big_endian) {
-    output[1] = (nbuf[0] << 4) | (nbuf[1]);
-    output[0] = (nbuf[2] << 4) | (nbuf[3]);
-  }
-  else {
-    output[0] = (nbuf[0] << 4) | (nbuf[1]);
-    output[1] = (nbuf[2] << 4) | (nbuf[3]);
-  }
+  if (!target_big_endian)
+    {
+      output[1] = (nbuf[0] << 4) | (nbuf[1]);
+      output[0] = (nbuf[2] << 4) | (nbuf[3]);
+    }
+  else
+    {
+      output[0] = (nbuf[0] << 4) | (nbuf[1]);
+      output[1] = (nbuf[2] << 4) | (nbuf[3]);
+    }
 }
 
 /* Find an opcode at the start of *STR_P in the hash table, and set
@@ -1403,7 +1397,8 @@ find_cooked_opcode (str_p)
   unsigned char *op_end;
   char name[20];
   int nlen = 0;
-  /* Drop leading whitespace */
+
+  /* Drop leading whitespace.  */
   while (*str == ' ')
     str++;
 
@@ -1428,19 +1423,19 @@ find_cooked_opcode (str_p)
       name[nlen] = c;
       nlen++;
     }
+
   name[nlen] = 0;
   *str_p = op_end;
 
   if (nlen == 0)
-    {
-      as_bad (_("can't find opcode "));
-    }
+    as_bad (_("can't find opcode "));
 
   return (sh_opcode_info *) hash_find (opcode_hash_control, name);
 }
 
 /* Assemble a parallel processing insn.  */
 #define DDT_BASE 0xf000 /* Base value for double data transfer insns */
+
 static void
 assemble_ppi (op_end, opcode)
      char *op_end;
@@ -1467,7 +1462,7 @@ assemble_ppi (op_end, opcode)
       opcode = get_specific (opcode, operand);
       if (opcode == 0)
 	{
-	  /* Couldn't find an opcode which matched the operands */
+	  /* Couldn't find an opcode which matched the operands.  */
 	  char *where = frag_more (2);
 
 	  where[0] = 0x0;
@@ -1475,6 +1470,7 @@ assemble_ppi (op_end, opcode)
 	  as_bad (_("invalid operands for opcode"));
 	  return;
 	}
+
       if (opcode->nibbles[0] != PPI)
 	as_bad (_("insn can't be combined with parallel processing insn"));
 
@@ -1646,8 +1642,7 @@ assemble_ppi (op_end, opcode)
 
 /* This is the guts of the machine-dependent assembler.  STR points to a
    machine dependent instruction.  This function is supposed to emit
-   the frags/bytes it assembles to.
- */
+   the frags/bytes it assembles to.  */
 
 void
 md_assemble (str)
@@ -1705,7 +1700,7 @@ md_assemble (str)
 
       if (opcode == 0)
 	{
-	  /* Couldn't find an opcode which matched the operands */
+	  /* Couldn't find an opcode which matched the operands.  */
 	  char *where = frag_more (2);
 
 	  where[0] = 0x0;
@@ -1739,7 +1734,7 @@ sh_frob_label ()
       offset = frag_now_fix ();
       if (frag_now != last_label_frag
 	  || offset != last_label_offset)
-	{	
+	{
 	  fix_new (frag_now, offset, 2, &abs_symbol, 0, 0, BFD_RELOC_SH_LABEL);
 	  last_label_frag = frag_now;
 	  last_label_offset = offset;
@@ -1789,14 +1784,15 @@ tc_headers_hook (headers)
 #endif
 #endif
 
-/* Various routines to kill one day */
-/* Equal to MAX_PRECISION in atof-ieee.c */
+/* Various routines to kill one day.  */
+/* Equal to MAX_PRECISION in atof-ieee.c.  */
 #define MAX_LITTLENUMS 6
 
-/* Turn a string in input_line_pointer into a floating point constant of type
-   type, and store the appropriate bytes in *litP.  The number of LITTLENUMS
-   emitted is stored in *sizeP .  An error message is returned, or NULL on OK.
- */
+/* Turn a string in input_line_pointer into a floating point constant
+   of type TYPE, and store the appropriate bytes in *LITP.  The number
+   of LITTLENUMS emitted is stored in *SIZEP .  An error message is
+   returned, or NULL on OK.  */
+
 char *
 md_atof (type, litP, sizeP)
      int type;
@@ -1845,7 +1841,7 @@ md_atof (type, litP, sizeP)
 	  litP += 2;
 	}
     }
-     
+
   return NULL;
 }
 
@@ -1878,8 +1874,8 @@ s_uses (ignore)
 }
 
 CONST char *md_shortopts = "";
-struct option md_longopts[] = {
-
+struct option md_longopts[] =
+{
 #define OPTION_RELAX  (OPTION_MD_BASE)
 #define OPTION_LITTLE (OPTION_MD_BASE + 1)
 #define OPTION_SMALL (OPTION_LITTLE + 1)
@@ -1891,7 +1887,7 @@ struct option md_longopts[] = {
   {"dsp", no_argument, NULL, OPTION_DSP},
   {NULL, no_argument, NULL, 0}
 };
-size_t md_longopts_size = sizeof(md_longopts);
+size_t md_longopts_size = sizeof (md_longopts);
 
 int
 md_parse_option (c, arg)
@@ -1928,7 +1924,7 @@ void
 md_show_usage (stream)
      FILE *stream;
 {
-  fprintf(stream, _("\
+  fprintf (stream, _("\
 SH options:\n\
 -little			generate little endian code\n\
 -relax			alter jump instructions for long displacements\n\
@@ -1958,7 +1954,6 @@ struct sh_count_relocs
    symbol.  When using BFD_ASSEMBLER, this is called via
    bfd_map_over_sections.  */
 
-/*ARGSUSED*/
 static void
 sh_count_relocs (abfd, sec, data)
      bfd *abfd ATTRIBUTE_UNUSED;
@@ -1988,7 +1983,6 @@ sh_count_relocs (abfd, sec, data)
 /* Handle the count relocs for a particular section.  When using
    BFD_ASSEMBLER, this is called via bfd_map_over_sections.  */
 
-/*ARGSUSED*/
 static void
 sh_frob_section (abfd, sec, ignore)
      bfd *abfd ATTRIBUTE_UNUSED;
@@ -2054,8 +2048,8 @@ sh_frob_section (abfd, sec, ignore)
 	  continue;
 	}
 
-      /* fscan should also be a fixup to a local symbol in the same
-	 section.  */
+      /* The variable fscan should also be a fixup to a local symbol
+	 in the same section.  */
       sym = fscan->fx_addsy;
       if (sym == NULL
 	  || fscan->fx_subsy != NULL
@@ -2168,15 +2162,16 @@ md_convert_frag (headers, seg, fragP)
 		(unsigned long) fragP->fr_address);
       else if (S_IS_DEFINED (fragP->fr_symbol))
 	as_bad (_("at 0x%lx, displacement to defined symbol %s overflows 12-bit field"),
-		(unsigned long) fragP->fr_address,		
+		(unsigned long) fragP->fr_address,
 		S_GET_NAME (fragP->fr_symbol));
       else
 	as_bad (_("at 0x%lx, displacement to undefined symbol %s overflows 12-bit field"),
-		(unsigned long) fragP->fr_address,		
+		(unsigned long) fragP->fr_address,
 		S_GET_NAME (fragP->fr_symbol));
 
-#if 0				/* This code works, but generates poor code and the compiler
-				   should never produce a sequence that requires it to be used.  */
+#if 0
+      /* This code works, but generates poor code and the compiler
+	 should never produce a sequence that requires it to be used.  */
 
       /* A jump wont fit in 12 bits, make code which looks like
 	 bra foo
@@ -2186,23 +2181,23 @@ md_convert_frag (headers, seg, fragP)
 	 */
       int t = buffer[0] & 0x10;
 
-      buffer[highbyte] = 0xa0;	/* branch over move and disp */
-      buffer[lowbyte] = 3;
-      buffer[highbyte+2] = 0xd0 | JREG;	/* Build mov insn */
-      buffer[lowbyte+2] = 0x00;
+      buffer[highbyte     ] = 0xa0;	/* branch over move and disp */
+      buffer[lowbyte      ] = 3;
+      buffer[highbyte +  2] = 0xd0 | JREG;	/* Build mov insn */
+      buffer[lowbyte  +  2] = 0x00;
 
-      buffer[highbyte+4] = 0;	/* space for 32 bit jump disp */
-      buffer[lowbyte+4] = 0;
-      buffer[highbyte+6] = 0;
-      buffer[lowbyte+6] = 0;
+      buffer[highbyte +  4] = 0;	/* space for 32 bit jump disp */
+      buffer[lowbyte  +  4] = 0;
+      buffer[highbyte +  6] = 0;
+      buffer[lowbyte  +  6] = 0;
 
-      buffer[highbyte+8] = 0x40 | JREG;	/* Build jmp @JREG */
-      buffer[lowbyte+8] = t ? 0xb : 0x2b;
+      buffer[highbyte +  8] = 0x40 | JREG;	/* Build jmp @JREG */
+      buffer[lowbyte  +  8] = t ? 0xb : 0x2b;
 
-      buffer[highbyte+10] = 0x20; /* build nop */
-      buffer[lowbyte+10] = 0x0b;
+      buffer[highbyte + 10] = 0x20; /* build nop */
+      buffer[lowbyte  + 10] = 0x0b;
 
-      /* Make reloc for the long disp */
+      /* Make reloc for the long disp.  */
       fix_new (fragP,
 	       fragP->fr_fix + 4,
 	       4,
@@ -2219,13 +2214,13 @@ md_convert_frag (headers, seg, fragP)
 
     case C (COND_JUMP, COND12):
     case C (COND_JUMP_DELAY, COND12):
-      /* A bcond won't fit, so turn it into a b!cond; bra disp; nop */
+      /* A bcond won't fit, so turn it into a b!cond; bra disp; nop.  */
       /* I found that a relax failure for gcc.c-torture/execute/930628-1.c
 	 was due to gas incorrectly relaxing an out-of-range conditional
 	 branch with delay slot.  It turned:
                      bf.s    L6              (slot mov.l   r12,@(44,r0))
          into:
-   
+
 2c:  8f 01 a0 8b     bf.s    32 <_main+32>   (slot bra       L6)
 30:  00 09           nop
 32:  10 cb           mov.l   r12,@(44,r0)
@@ -2287,19 +2282,20 @@ md_convert_frag (headers, seg, fragP)
     case C (COND_JUMP, UNDEF_WORD_DISP):
     case C (COND_JUMP_DELAY, UNDEF_WORD_DISP):
       if (fragP->fr_symbol == NULL)
-	as_bad (_("at 0x%lx, displacement overflows 8-bit field"), 
+	as_bad (_("at 0x%lx, displacement overflows 8-bit field"),
 		(unsigned long) fragP->fr_address);
       else if (S_IS_DEFINED (fragP->fr_symbol))
 	as_bad (_("at 0x%lx, displacement to defined symbol %s overflows 8-bit field "),
-		(unsigned long) fragP->fr_address,		
+		(unsigned long) fragP->fr_address,
 		S_GET_NAME (fragP->fr_symbol));
       else
 	as_bad (_("at 0x%lx, displacement to undefined symbol %s overflows 8-bit field "),
-		(unsigned long) fragP->fr_address,		
+		(unsigned long) fragP->fr_address,
 		S_GET_NAME (fragP->fr_symbol));
 
-#if 0				/* This code works, but generates poor code, and the compiler
-				   should never produce a sequence that requires it to be used.  */
+#if 0
+      /* This code works, but generates poor code, and the compiler
+	 should never produce a sequence that requires it to be used.  */
 
       /* A bcond won't fit and it won't go into a 12 bit
 	 displacement either, the code sequence looks like:
@@ -2513,7 +2509,7 @@ sh_fix_adjustable (fixP)
 
   if (fixP->fx_addsy == NULL)
     return 1;
-  
+
   /* We need the symbol name for the VTABLE entries */
   if (fixP->fx_r_type == BFD_RELOC_VTABLE_INHERIT
       || fixP->fx_r_type == BFD_RELOC_VTABLE_ENTRY)
@@ -2522,7 +2518,8 @@ sh_fix_adjustable (fixP)
   return 1;
 }
 
-void sh_elf_final_processing()
+void
+sh_elf_final_processing ()
 {
   int val;
 
@@ -2574,9 +2571,9 @@ md_apply_fix (fixP, val)
   int shift;
 
 #ifdef BFD_ASSEMBLER
-  /* adjust_reloc_syms won't convert a reloc against a weak symbol
-     into a reloc against a section, but bfd_install_relocation will
-     screw up if the symbol is defined, so we have to adjust val here
+  /* The function adjust_reloc_syms won't convert a reloc against a weak
+     symbol into a reloc against a section, but bfd_install_relocation
+     will screw up if the symbol is defined, so we have to adjust val here
      to avoid the screw up later.  */
   if (fixP->fx_addsy != NULL
       && S_IS_WEAK (fixP->fx_addsy))
@@ -2637,7 +2634,7 @@ md_apply_fix (fixP, val)
          Note that adding further restrictions may invalidate
          reasonable looking assembly code, such as ``and -0x1,r0''.  */
       max = 0xff;
-      min = - 0xff;
+      min = -0xff;
       *buf++ = val;
       break;
 
@@ -2684,14 +2681,14 @@ md_apply_fix (fixP, val)
       break;
 
     case BFD_RELOC_32:
-      if (! target_big_endian) 
+      if (!target_big_endian)
 	{
 	  *buf++ = val >> 0;
 	  *buf++ = val >> 8;
 	  *buf++ = val >> 16;
 	  *buf++ = val >> 24;
 	}
-      else 
+      else
 	{
 	  *buf++ = val >> 24;
 	  *buf++ = val >> 16;
@@ -2705,8 +2702,8 @@ md_apply_fix (fixP, val)
 	{
 	  *buf++ = val >> 0;
 	  *buf++ = val >> 8;
-	} 
-      else 
+	}
+      else
 	{
 	  *buf++ = val >> 8;
 	  *buf++ = val >> 0;
@@ -2771,7 +2768,7 @@ md_estimate_size_before_relax (fragP, segment_type)
   switch (fragP->fr_subtype)
     {
     case C (UNCOND_JUMP, UNDEF_DISP):
-      /* used to be a branch to somewhere which was unknown */
+      /* Used to be a branch to somewhere which was unknown.  */
       if (!fragP->fr_symbol)
 	{
 	  fragP->fr_subtype = C (UNCOND_JUMP, UNCOND12);
@@ -2794,20 +2791,20 @@ md_estimate_size_before_relax (fragP, segment_type)
       abort ();
     case C (COND_JUMP, UNDEF_DISP):
     case C (COND_JUMP_DELAY, UNDEF_DISP):
-      /* used to be a branch to somewhere which was unknown */
+      /* Used to be a branch to somewhere which was unknown.  */
       if (fragP->fr_symbol
 	  && S_GET_SEGMENT (fragP->fr_symbol) == segment_type)
 	{
 	  int what = GET_WHAT (fragP->fr_subtype);
 	  /* Got a symbol and it's defined in this segment, become byte
-	     sized - maybe it will fix up */
+	     sized - maybe it will fix up.  */
 	  fragP->fr_subtype = C (what, COND8);
 	  fragP->fr_var = md_relax_table[C (what, COND8)].rlx_length;
 	}
       else if (fragP->fr_symbol)
 	{
 	  int what = GET_WHAT (fragP->fr_subtype);
-	  /* Its got a segment, but its not ours, so it will always be long */
+	  /* Its got a segment, but its not ours, so it will always be long.  */
 	  fragP->fr_subtype = C (what, UNDEF_WORD_DISP);
 	  fragP->fr_var = md_relax_table[C (what, COND32)].rlx_length;
 	  return md_relax_table[C (what, COND32)].rlx_length;
@@ -2815,7 +2812,7 @@ md_estimate_size_before_relax (fragP, segment_type)
       else
 	{
 	  int what = GET_WHAT (fragP->fr_subtype);
-	  /* We know the abs value */
+	  /* We know the abs value.  */
 	  fragP->fr_subtype = C (what, COND8);
 	  fragP->fr_var = md_relax_table[C (what, COND8)].rlx_length;
 	}
@@ -2825,7 +2822,7 @@ md_estimate_size_before_relax (fragP, segment_type)
   return fragP->fr_var;
 }
 
-/* Put number into target byte order */
+/* Put number into target byte order.  */
 
 void
 md_number_to_chars (ptr, use, nbytes)
