@@ -15,7 +15,8 @@
    
    You should have received a copy of the GNU General Public License
    along with GAS; see the file COPYING.  If not, write to
-   the Free Software Foundation, 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.  */
+   the Free Software Foundation, 59 Temple Place - Suite 330, Boston, MA
+   02111-1307, USA.  */
 
 #define TE_386BSD	1
 
@@ -28,4 +29,4 @@
  * End:
  */
 
-/* end of te-sun3.h */
+/* end of te-386bsd.h */
