@@ -21,5 +21,8 @@
 /* HP PA-RISC and OSF/1 support was contributed by the Center for
 	Software Science at the University of Utah.  */
 
+/* Labels are not required to have a colon for a suffix.  */
+#define LABELS_WITHOUT_COLONS 1
+
 /* These define interfaces.  */
 #include "obj-format.h"
