@@ -81,7 +81,6 @@ static char *default_excluded_list[] =
 #define OPTION_DEMANGLE		(150)
 #define OPTION_NO_DEMANGLE	(OPTION_DEMANGLE + 1)
 #define OPTION_DEMANGLER	(OPTION_NO_DEMANGLE + 1)
-#define OPTION_STYLE		(OPTION_DEMANGLER + 1)
 
 static struct option long_options[] =
 {
@@ -107,7 +106,7 @@ static struct option long_options[] =
     /* various options to affect output: */
 
   {"all-lines", no_argument, 0, 'x'},
-  {"demangle", no_argument, 0, OPTION_DEMANGLE},
+  {"demangle", optional_argument, 0, OPTION_DEMANGLE},
   {"no-demangle", no_argument, 0, OPTION_NO_DEMANGLE},
   {"demangler", required_argument, NULL, OPTION_DEMANGLER},
   {"directory-path", required_argument, 0, 'I'},
@@ -116,7 +115,6 @@ static struct option long_options[] =
   {"print-path", no_argument, 0, 'L'},
   {"separate-files", no_argument, 0, 'y'},
   {"static-call-graph", no_argument, 0, 'c'},
-  {"style", required_argument, NULL, OPTION_STYLE},
   {"table-length", required_argument, 0, 't'},
   {"time", required_argument, 0, 'n'},
   {"no-time", required_argument, 0, 'N'},
@@ -157,12 +155,10 @@ Usage: %s [-[abcDhilLsTvwxyz]] [-[ACeEfFJnNOpPqQZ][name]] [-I dirs]\n\
 	[--no-static] [--print-path] [--separate-files]\n\
 	[--static-call-graph] [--sum] [--table-length=len] [--traditional]\n\
 	[--version] [--width=n] [--ignore-non-functions]\n\
-	[--demangle] [--no-demangle]\n\
-	[--demangler=dso:function]\n"), whoami);
-  fprintf (stream, _("\
-	[--style=%s]\n\
+	[--demangle[=%s]]\n\
+	[--no-demangle] [--demangler=dso:function]\n\
 	[image-file] [profile-file...]\n"),
-	   get_demangler_list ());
+	   whoami, get_demangler_list ());
   if (status == 0)
     fprintf (stream, _("Report bugs to %s\n"), REPORT_BUGS_TO);
   done (status);
@@ -433,6 +429,8 @@ This program is free software.  This program has absolutely no warranty.\n"));
 	  break;
 	case OPTION_DEMANGLE:
 	  demangle = TRUE;
+	  if (optarg != NULL)
+	    style = optarg;
 	  break;
 	case OPTION_NO_DEMANGLE:
 	  demangle = FALSE;
@@ -440,9 +438,6 @@ This program is free software.  This program has absolutely no warranty.\n"));
 	case OPTION_DEMANGLER:
 	  demangler = optarg;
 	  break;
-	case OPTION_STYLE:
-	  style = optarg;
-	  break;
 	default:
 	  usage (stderr, 1);
 	}
