@@ -371,6 +371,7 @@ struct lang_nocrossrefs
 extern struct lang_nocrossrefs *nocrossref_list;
 
 extern lang_output_section_statement_type *abs_output_section;
+extern lang_statement_list_type lang_output_section_statement;
 extern boolean lang_has_input_file;
 extern etree_type *base;
 extern lang_statement_list_type *stat_ptr;
@@ -378,6 +379,7 @@ extern boolean delete_output_file_on_failure;
 
 extern const char *entry_symbol;
 extern boolean entry_from_cmdline;
+extern lang_statement_list_type file_chain;
 
 extern void lang_init PARAMS ((void));
 extern struct memory_region_struct *lang_memory_region_lookup
@@ -388,7 +390,7 @@ extern void lang_map PARAMS ((void));
 extern void lang_set_flags PARAMS ((lang_memory_region_type *, const char *,
 				    int));
 extern void lang_add_output PARAMS ((const char *, int from_script));
-extern void lang_enter_output_section_statement
+extern lang_output_section_statement_type *lang_enter_output_section_statement
   PARAMS ((const char *output_section_statement_name,
 	   etree_type * address_exp,
 	   enum section_type sectype,
@@ -429,7 +431,6 @@ extern bfd_vma lang_do_assignments
 	   bfd_vma dot));
 
 #define LANG_FOR_EACH_INPUT_STATEMENT(statement)		\
-  extern lang_statement_list_type file_chain;			\
   lang_input_statement_type *statement;				\
   for (statement = (lang_input_statement_type *)file_chain.head;\
        statement != (lang_input_statement_type *)NULL;		\
