@@ -1,5 +1,6 @@
 /* ldver.c -- Print linker version.
-   Copyright (C) 1991, 92, 93, 94, 95, 1996 Free Software Foundation, Inc.
+   Copyright (C) 1991, 92, 93, 94, 95, 96, 97, 2000
+   Free Software Foundation, Inc.
 
 This file is part of GLD, the Gnu Linker.
 
@@ -23,23 +24,26 @@ Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.  */
 
 #include "ld.h"
 #include "ldver.h"
+#include "ldexp.h"
+#include "ldlang.h"
+#include "ldfile.h"
 #include "ldemul.h"
 #include "ldmain.h"
 
-const char *ld_program_version = "2.8";
+const char *ld_program_version = VERSION;
 
 void
 ldversion (noisy)
      int noisy;
 {
-  fprintf (stdout, "GNU ld version %s (with BFD %s)\n",
+  fprintf (stdout, _("GNU ld version %s (with BFD %s)\n"),
 	   ld_program_version, BFD_VERSION);
 
   if (noisy) 
     {
       ld_emulation_xfer_type **ptr = ld_emulations;
     
-      printf ("  Supported emulations:\n");
+      printf (_("  Supported emulations:\n"));
       while (*ptr) 
 	{
 	  printf ("   %s\n", (*ptr)->emulation_name);
