@@ -96,8 +96,7 @@ int parsing_defsym = 0;
 #define OPTION_SONAME			(OPTION_SHARED + 1)
 #define OPTION_SORT_COMMON		(OPTION_SONAME + 1)
 #define OPTION_STATS			(OPTION_SORT_COMMON + 1)
-#define OPTION_STYLE			(OPTION_STATS + 1)
-#define OPTION_SYMBOLIC			(OPTION_STYLE + 1)
+#define OPTION_SYMBOLIC			(OPTION_STATS + 1)
 #define OPTION_TASK_LINK		(OPTION_SYMBOLIC + 1)
 #define OPTION_TBSS			(OPTION_TASK_LINK + 1)
 #define OPTION_TDATA			(OPTION_TBSS + 1)
@@ -241,8 +240,10 @@ static const struct ld_option ld_options[] =
       'y', N_("SYMBOL"), N_("Trace mentions of SYMBOL"), TWO_DASHES },
   { {NULL, required_argument, NULL, '\0'},
       'Y', N_("PATH"), N_("Default search path for Solaris compatibility"), ONE_DASH },
+#if 0
   { {NULL, required_argument, NULL, '\0'},
       'z', N_("KEYWORD"), N_("Ignored for Solaris compatibility"), ONE_DASH },
+#endif
   { {"start-group", no_argument, NULL, '('},
       '(', NULL, N_("Start a group"), TWO_DASHES },
   { {"end-group", no_argument, NULL, ')'},
@@ -274,8 +275,8 @@ static const struct ld_option ld_options[] =
       '\0', NULL, N_("Output cross reference table"), TWO_DASHES },
   { {"defsym", required_argument, NULL, OPTION_DEFSYM},
       '\0', N_("SYMBOL=EXPRESSION"), N_("Define a symbol"), TWO_DASHES },
-  { {"demangle", no_argument, NULL, OPTION_DEMANGLE},
-      '\0', NULL, N_("Demangle symbol names"), TWO_DASHES },
+  { {"demangle", optional_argument, NULL, OPTION_DEMANGLE},
+      '\0', N_("[=STYLE]"), N_("Demangle symbol names [using STYLE]"), TWO_DASHES },
   { {"demangler", no_argument, NULL, OPTION_DEMANGLER},
       '\0', "DSO:FUNCTION", N_("Set DSO and demangler function"), TWO_DASHES },
   { {"dynamic-linker", required_argument, NULL, OPTION_DYNAMIC_LINKER},
@@ -341,8 +342,6 @@ static const struct ld_option ld_options[] =
       '\0', N_("COUNT"), N_("Split output sections every COUNT relocs"), TWO_DASHES },
   { {"stats", no_argument, NULL, OPTION_STATS},
       '\0', NULL, N_("Print memory usage statistics"), TWO_DASHES },
-  { {"style", required_argument, NULL, OPTION_STYLE},
-      '\0', demangler_list_buffer, N_("Set demangling style"), TWO_DASHES },
   { {"task-link", required_argument, NULL, OPTION_TASK_LINK},
       '\0', N_("SYMBOL"), N_("Do task level linking"), TWO_DASHES },
   { {"traditional-format", no_argument, NULL, OPTION_TRADITIONAL_FORMAT},
@@ -603,6 +602,8 @@ parse_args (argc, argv)
 	  break;
 	case OPTION_DEMANGLE:
 	  demangling = true;
+	  if (optarg != NULL)
+	    style = optarg;
 	  break;
 	case OPTION_DEMANGLER:
 	  demangler = optarg;
@@ -848,9 +849,6 @@ parse_args (argc, argv)
 	case OPTION_STATS:
 	  config.stats = true;
 	  break;
-	case OPTION_STYLE:
-	  style = optarg;
-	  break;
 	case OPTION_SYMBOLIC:
 	  link_info.symbolic = true;
 	  break;
@@ -868,6 +866,8 @@ parse_args (argc, argv)
 	case OPTION_SECTION_START:
 	  {
 	    char *optarg2;
+	    char *sec_name;
+	    int len;
 
 	    /* Check for <something>=<somthing>...  */
 	    optarg2 = strchr (optarg, '=');
@@ -890,12 +890,15 @@ parse_args (argc, argv)
 		xexit (1);
 	      }
 
-	    optarg2[-1] = '\0';
+	    /* We must copy the section name as set_section_start
+	       doesn't do it for us.  */
+	    len = optarg2 - optarg;
+	    sec_name = xmalloc (len);
+	    memcpy (sec_name, optarg, len - 1);
+	    sec_name[len - 1] = 0;
 
 	    /* Then set it...  */
-	    set_section_start (optarg, optarg2);
-	    
-	    optarg2[-1] = '=';
+	    set_section_start (sec_name, optarg2);
 	  }
 	  break;
 	case OPTION_TBSS:
@@ -1010,11 +1013,13 @@ the GNU General Public License.  This program has absolutely no warranty.\n"));
 	case 'y':
 	  add_ysym (optarg);
 	  break;
+#if 0
 	case 'z':
 	  /* We accept and ignore this option for Solaris
              compatibility.  Actually, on Solaris, optarg is not
              ignored.  Someday we should handle it correctly.  FIXME.  */
 	  break;
+#endif
 	case OPTION_SPLIT_BY_RELOC:
 	  config.split_by_reloc = strtoul (optarg, NULL, 0);
 	  break; 
@@ -1226,5 +1231,8 @@ help ()
   ldemul_list_emulation_options (stdout);
   printf ("\n");
 
+  printf (_("\nSupported demangler style: %s\n\n"),
+ 	  get_demangler_list ());
+
   printf (_("Report bugs to %s\n"), REPORT_BUGS_TO);
 }
