@@ -34,6 +34,7 @@
 #include "ldmisc.h"
 #include "ldgram.h"
 #include "ldmain.h"
+#include "ldfile.h"
 #include "ldemul.h"
 #include "coff/internal.h"
 #include "../bfd/libcoff.h"
@@ -86,6 +87,9 @@ typedef struct {
 } pe_details_type;
 
 #define PE_ARCH_i386	1
+#define PE_ARCH_sh	2
+#define PE_ARCH_mips	3
+#define PE_ARCH_arm	4
 
 static pe_details_type pe_detail_list[] = {
   {
@@ -96,6 +100,30 @@ static pe_details_type pe_detail_list[] = {
     bfd_arch_i386,
     1
   },
+  {
+    "pei-shl",
+    "pe-shl",
+    16 /* R_SH_IMAGEBASE */,
+    PE_ARCH_sh,
+    bfd_arch_sh,
+    1
+  },
+  {
+    "pei-mips",
+    "pe-mips",
+    34 /* MIPS_R_RVA */,
+    PE_ARCH_mips,
+    bfd_arch_mips,
+    0
+  },
+  {
+    "pei-arm-little",
+    "pe-arm-little",
+    11 /* ARM_RVA32 */,
+    PE_ARCH_arm,
+    bfd_arch_arm,
+    0
+  },
   { NULL, NULL, 0, 0, 0, 0 }
 };
 
@@ -109,7 +137,8 @@ pe_dll_id_target (target)
 {
   int i;
   for (i=0; pe_detail_list[i].target_name; i++)
-    if (strcmp (pe_detail_list[i].target_name, target) == 0)
+    if (strcmp (pe_detail_list[i].target_name, target) == 0
+	|| strcmp (pe_detail_list[i].object_target, target) == 0)
       {
 	pe_details = pe_detail_list+i;
 	return;
@@ -273,8 +302,7 @@ process_def_file (abfd, info)
 
 	  for (j = 0; j < nsyms; j++)
 	    {
-	      if ((symbols[j]->flags & (BSF_FUNCTION | BSF_GLOBAL))
-		  == (BSF_FUNCTION | BSF_GLOBAL))
+	      if (symbols[j]->flags & BSF_GLOBAL)
 		{
 		  const char *sn = symbols[j]->name;
 		  if (*sn == '_')
@@ -403,7 +431,7 @@ process_def_file (abfd, info)
 	    exported_symbol_sections[i] = blhe->u.def.section;
 	  else
 	    exported_symbol_sections[i] = blhe->u.c.p->section;
-
+	  
 	  if (pe_def_file->exports[i].ordinal != -1)
 	    {
 	      if (max_ordinal < pe_def_file->exports[i].ordinal)
@@ -590,15 +618,12 @@ generate_edata (abfd, info)
 
 static void
 fill_exported_offsets (abfd, info)
-     bfd *abfd;
+     bfd *abfd ATTRIBUTE_UNUSED;
      struct bfd_link_info *info;
 {
-  int i, j;
+  int i;
   struct bfd_link_hash_entry *blhe;
-  bfd *b;
-  struct sec *s;
-  def_file_export *e=0;
-
+  
   for (i = 0; i < pe_def_file->num_exports; i++)
     {
       char *name = (char *) xmalloc (strlen (pe_def_file->exports[i].internal_name) + 2);
@@ -776,13 +801,32 @@ generate_reloc (abfd, info)
 			     + sym->section->output_offset
 			     + sym->section->output_section->vma);
 		  reloc_data[total_relocs].vma = sec_vma + relocs[i]->address;
-		  switch (relocs[i]->howto->bitsize*1000
-			  + relocs[i]->howto->rightshift)
+		  
+#define BITS_AND_SHIFT(bits, shift) (bits * 1000 | shift)
+				    
+		  switch BITS_AND_SHIFT (relocs[i]->howto->bitsize,
+					 relocs[i]->howto->rightshift)
 		    {
-		    case 32000:
+		    case BITS_AND_SHIFT (32, 0):
 		      reloc_data[total_relocs].type = 3;
 		      total_relocs++;
 		      break;
+		    case BITS_AND_SHIFT (16, 0):
+		      reloc_data[total_relocs].type = 2;
+		      total_relocs++;
+		      break;
+		    case BITS_AND_SHIFT (16, 16):
+		      reloc_data[total_relocs].type = 4;
+		      /* FIXME: we can't know the symbol's right value yet,
+			 but we probably can safely assume that CE will relocate
+			 us in 64k blocks, so leaving it zero is safe.  */
+		      reloc_data[total_relocs].extra = 0;
+		      total_relocs++;
+		      break;
+		    case BITS_AND_SHIFT (26, 2):
+		      reloc_data[total_relocs].type = 5;
+		      total_relocs++;
+		      break;
 		    default:
 		      /* xgettext:c-format */
 		      einfo (_("%XError: %d-bit reloc in dll\n"),
@@ -807,13 +851,18 @@ generate_reloc (abfd, info)
   for (i = 0; i < total_relocs; i++)
     {
       unsigned long this_page = (reloc_data[i].vma >> 12);
+      
       if (this_page != sec_page)
 	{
 	  reloc_sz = (reloc_sz + 3) & ~3;	/* 4-byte align */
 	  reloc_sz += 8;
 	  sec_page = this_page;
 	}
+      
       reloc_sz += 2;
+      
+      if (reloc_data[i].type == 4)
+	reloc_sz += 2;
     }
   reloc_sz = (reloc_sz + 3) & ~3;	/* 4-byte align */
 
@@ -1319,6 +1368,31 @@ static unsigned char jmp_ix86_bytes[] = {
   0xff, 0x25, 0x00, 0x00, 0x00, 0x00, 0x90, 0x90
 };
 
+/*
+ *_function:
+ *	mov.l	ip+8,r0
+ *	mov.l	@r0,r0
+ *	jmp	@r0
+ *	nop
+ *	.dw	__imp_function
+ */
+
+static unsigned char jmp_sh_bytes[] = {
+  0x01, 0xd0, 0x02, 0x60, 0x2b, 0x40, 0x09, 0x00, 0x00, 0x00, 0x00, 0x00
+};
+
+/*
+ *_function:
+ *	lui	$t0,<high:__imp_function>
+ *	lw	$t0,<low:__imp_function>
+ *	jr	$t0
+ *	nop
+ */
+
+static unsigned char jmp_mips_bytes[] = {
+  0x00, 0x00, 0x08, 0x3c,  0x00, 0x00, 0x08, 0x8d,
+  0x08, 0x00, 0x00, 0x01,  0x00, 0x00, 0x00, 0x00
+};
 
 static bfd *
 make_one (exp, parent)
@@ -1326,12 +1400,12 @@ make_one (exp, parent)
      bfd *parent;
 {
   asection *tx, *id7, *id5, *id4, *id6;
-  unsigned char *td, *d7, *d5, *d4, *d6;
+  unsigned char *td, *d7, *d5, *d4, *d6 = NULL;
   int len;
   char *oname;
   bfd *abfd;
-  unsigned char *jmp_bytes;
-  int jmp_byte_count;
+  unsigned char *jmp_bytes = NULL;
+  int jmp_byte_count = 0;
 
   switch (pe_details->pe_arch)
     {
@@ -1339,6 +1413,14 @@ make_one (exp, parent)
       jmp_bytes = jmp_ix86_bytes;
       jmp_byte_count = sizeof (jmp_ix86_bytes);
       break;
+    case PE_ARCH_sh:
+      jmp_bytes = jmp_sh_bytes;
+      jmp_byte_count = sizeof (jmp_sh_bytes);
+      break;
+    case PE_ARCH_mips:
+      jmp_bytes = jmp_mips_bytes;
+      jmp_byte_count = sizeof (jmp_mips_bytes);
+      break;
     }
 
   oname = (char *) xmalloc (20);
@@ -1362,7 +1444,7 @@ make_one (exp, parent)
   if (! exp->flag_data)
     quick_symbol (abfd, U(""), exp->internal_name, "", tx, BSF_GLOBAL, 0);
   quick_symbol (abfd, U("_head_"), dll_symname, "", UNDSEC, BSF_GLOBAL, 0);
-  quick_symbol (abfd, U("__imp_"), exp->internal_name, "", id5, BSF_GLOBAL, 0);
+  quick_symbol (abfd, U("_imp__"), exp->internal_name, "", id5, BSF_GLOBAL, 0);
   if (pe_dll_compat_implib)
     quick_symbol (abfd, U("__imp_"), exp->internal_name, "", 
                   id5, BSF_GLOBAL, 0);
@@ -1376,6 +1458,14 @@ make_one (exp, parent)
     case PE_ARCH_i386:
       quick_reloc (abfd, 2, BFD_RELOC_32, 2);
       break;
+    case PE_ARCH_sh:
+      quick_reloc (abfd, 8, BFD_RELOC_32, 2);
+      break;
+    case PE_ARCH_mips:
+      quick_reloc (abfd, 0, BFD_RELOC_HI16_S, 2);
+      quick_reloc (abfd, 0, BFD_RELOC_LO16, 0); /* MIPS_R_PAIR */
+      quick_reloc (abfd, 4, BFD_RELOC_LO16, 2);
+      break;
     }
   save_relocs (tx);
 
@@ -1571,10 +1661,17 @@ pe_process_import_defs (output_bfd, link_info)
 	    struct bfd_link_hash_entry *blhe;
 
 	    /* see if we need this import */
-	    char *name = (char *) xmalloc (strlen (pe_def_file->imports[i].internal_name) + 2);
+	    char *name = (char *) xmalloc (strlen (pe_def_file->imports[i].internal_name) + 2 + 6);
 	    sprintf (name, "%s%s", U(""), pe_def_file->imports[i].internal_name);
 	    blhe = bfd_link_hash_lookup (link_info->hash, name,
 					 false, false, false);
+	    if (!blhe || (blhe && blhe->type != bfd_link_hash_undefined))
+	      {
+		sprintf (name, "%s%s", U("_imp__"),
+			 pe_def_file->imports[i].internal_name);
+		blhe = bfd_link_hash_lookup (link_info->hash, name,
+					     false, false, false);
+	      }
 	    free (name);
 	    if (blhe && blhe->type == bfd_link_hash_undefined)
 	      {
