@@ -1,3 +1,21 @@
+#ifdef PROTECTED_CHECK
+#include <features.h>
+
+int
+main (argc, argv)
+  int argc;
+  char *argv[];
+{
+#if defined (__GLIBC__) && (__GLIBC__ > 2 \
+			    || (__GLIBC__ == 2 \
+				&&  __GLIBC_MINOR__ >= 2))
+  puts ("yes");
+#else
+  puts ("no");
+#endif
+  return 0;
+}
+#else
 /* This is the main program for the shared library test.  */
 
 #include <stdio.h>
@@ -27,15 +45,17 @@ extern int visibility_varval ();
 extern void *visibility_varptr ();
 
 #ifdef HIDDEN_WEAK_TEST
-#define HIDDEN_UNDEF_TEST
 #define WEAK_TEST
 #endif
 
 #ifdef PROTECTED_WEAK_TEST
-#define PROTECTED_UNDEF_TEST
 #define WEAK_TEST
 #endif
 
+#ifdef PROTECTED_UNDEF_TEST
+#define PROTECTED_TEST
+#endif
+
 #ifndef WEAK_TEST
 extern int visibility ();
 extern int visibility_var;
@@ -156,3 +176,4 @@ main ()
 	  main_visibility_checkvar ());
   return 0;
 }
+#endif
